/* exported renderMultilineSecbySecChart */
/* global d3*/
function renderMultilineSecbySecChart(selector, config) {
  const width = config.width;
  const height = config.height;
  const paddingTop = config.paddingTop;
  const paddingBottom = config.paddingBottom;
  const paddingLeft = config.paddingLeft;
  const paddingRight = config.paddingRight;
  const data = config.data;
  const leftTransVal = config.leftTransVal;
  const colNamesMapping = config.colNamesMapping;
  var score_love,
    score_like,
    score_laughter,
    score_surprise,
    score_confusion,
    score_sad,
    score_dislike,
    score_angry,
    score_grand_total;

  // set the ranges
  var x = d3.scaleBand().range([leftTransVal, width]);
  var y = d3.scaleLinear().range([height, 0]);

  // define the line
  score_love = d3
    .line()
    .x(function (d) {
      return x(d.x_val);
    })
    .y(function (d) {
      return y(d.score_love);
    });

  // define the line
  score_like = d3
    .line()
    .x(function (d) {
      return x(d.x_val);
    })
    .y(function (d) {
      return y(d.score_like);
    });

  // define the line
  score_laughter = d3
    .line()
    .x(function (d) {
      return x(d.x_val);
    })
    .y(function (d) {
      return y(d.score_laughter);
    });
  // define the line
  score_surprise = d3
    .line()
    .x(function (d) {
      return x(d.x_val);
    })
    .y(function (d) {
      return y(d.score_surprise);
    });
  // define the line
  score_confusion = d3
    .line()
    .x(function (d) {
      return x(d.x_val);
    })
    .y(function (d) {
      return y(d.score_confusion);
    });
  // define the line
  score_sad = d3
    .line()
    .x(function (d) {
      return x(d.x_val);
    })
    .y(function (d) {
      return y(d.score_sad);
    });
  // define the line
  score_dislike = d3
    .line()
    .x(function (d) {
      return x(d.x_val);
    })
    .y(function (d) {
      return y(d.score_dislike);
    });
  // define the line
  score_angry = d3
    .line()
    .x(function (d) {
      return x(d.x_val);
    })
    .y(function (d) {
      return y(d.score_angry);
    });
  // define the line
  score_grand_total = d3
    .line()
    .x(function (d) {
      return x(d.x_val);
    })
    .y(function (d) {
      return y(d.score_grand_total);
    });
  score_love,
    score_like,
    score_laughter,
    score_surprise,
    score_confusion,
    score_sad,
    score_dislike,
    score_angry,
    score_grand_total;

  // append the svg object to the body of the page
  var svg = d3
    .select(selector)
    .append("svg")
    .attr("width", width + paddingLeft + paddingRight)
    .attr("height", height + paddingTop + paddingBottom)
    .append("g")
    .attr("transform", `translate(${paddingLeft}, ${paddingTop})`);

  var yMaxVal = d3.max(data, (d) => d["score_grand_total"]);

  // Scale the range of the data
  x.domain(
    data.map(function (d) {
      return d.x_val;
    })
  );
  y.domain([0, yMaxVal]).nice();

  // Add the valueline path.
  _.each(colNamesMapping, function (d, i) {
    var chartName_ = eval(i);
    svg
      .append("path")
      .attr("class", "multiline_secBysec")
      .attr("stroke", d)
      .attr("d", function () {
        return chartName_(data);
      });
  });

  svg
    .append("g")
    .attr("transform", `translate(0, 0)`)
    .attr("class", "multiline_axis")

    .call(d3.axisLeft(y).tickSize(0))
    .call((g) => g.select(".domain").remove());

  // add the x Axis
  svg
    .append("g")
    .attr("transform", `translate(${-leftTransVal}, ${height + 10})`)
    .attr("class", "multiline_axis")
    .call(d3.axisBottom(x).tickSize(0))
    .call((g) => g.select(".domain").remove());

  //Add horizontal gridline
  let grid_lines_dummy_data_mnth = [0];
  var grid_lines_mnth = svg.selectAll(".grid");
  grid_lines_mnth
    .data(grid_lines_dummy_data_mnth)
    .enter()
    .append("line")
    .attr("x1", 0)
    .attr("y1", height)
    .attr("x2", width-60)
    .attr("y2", height)
    .attr("stroke", "#E3E3E3");

  //Add tooltip:
  var div = d3
    .select("body")
    .append("div")
    .attr("class", "secBysecTooltip")
    .style("opacity", 0);

  //Add dots
  _.each(colNamesMapping, function (dotColor, colName) {
    svg
      .selectAll("dot")
      .data(data)
      .enter()
      .append("circle")
      .attr("r", 3)
      .attr("cx", function (d) {
        return x(d.x_val);
      })
      .attr("cy", function (d) {
        return y(d[colName]);
      })
      .attr("fill", dotColor)
      .attr("stroke-width", "1px")
      .on("mouseover", function (d, event) {
        div.style("opacity", 1);
        div
          .html(
            "<div class='heading-top'>" +
              "X : " +
              event["x_val"] +
              "</br>" +
              '<div class="heading-bottom">' +
              "Y : " +
              event[colName] +
              "</div>" +
              "</div>"
          )
          .style("left", d.pageX - 36 + "px")
          .style("top", d.pageY - 72 + "px");
      })
      .on("mouseleave", function () {
        div.transition().style("opacity", 0);
      });
  });
}
